@@ -1,6 +1,8 @@
 """
 All configurations for pymakehelper
 """
+import os
+
 import browser_cookie3
 from pytconf.config import Config, ParamCreator
 
@@ -138,15 +140,29 @@ class ConfigPornhubSearch(Config):
     )
 
 
-class ConfigYoutubeDl(Config):
+class ConfigYoutubeUrl(Config):
     """
-    Configuration to download a single url
+    Configuration for single url download
     """
     url = ParamCreator.create_str(
         help_string="the URL to download",
     )
 
 
+class ConfigYoutubeDl(Config):
+    """
+    Configuration for youtube downloads
+    """
+    use_archive = ParamCreator.create_bool(
+        help_string="Should we use an archive?",
+        default=True,
+    )
+    archive_file = ParamCreator.create_existing_file(
+        help_string="What file to use as archive?",
+        default=os.path.expanduser('~/.config/youtube-dl-archive'),
+    )
+
+
 class ConfigPornhubUrl(Config):
     """
     Parameters for what pornstar to download
